$(function () {
    var webSocket = getWebSocket(),
            queryMap = getQueryMap(),
            isDebug = localStorage.getItem('phantombot_overlay_debug') === 'true' || false;
    queue = [];

    const getWebSocket = () => {
        let socketUri = ((window.location.protocol === 'https:' ? 'wss://' : 'ws://') + window.location.host + '/ws/overlay'), // URI of the socket.
                reconnectInterval = 5000; // How often in milliseconds we should try reconnecting.

        return new ReconnectingWebSocket(socketUri, null, {
            reconnectInterval: reconnectInterval
        });
    }

    const getQueryMap = () => {
        let queryString = window.location.search,
            queryParts = queryString.substring(1).split('&'),
            queryMap = new Map();

        for (let part in queryParts) {
            let key = part.substring(0, part.indexOf('=')),
                value = part.substring(part.indexOf('=') + 1, part.length);
            if (key.length > 0 && value.length > 0) queryMap.set(key, value);
        }
        return queryMap;
    }

    const printDebug = (message, force) => {
        if (isDebug || force) console.log('%c[PhantomBot Log]', 'color: #6441a5; font-weight: 900;', message);
    }
    window.toggleDebug =  (toggle) => {
        localStorage.setItem('phantombot_overlay_debug', toggle.toString());
        window.location.reload();
    }

    const getOrElse = (option, def) => queryMap.has(option) ?  queryMap.get(option): def;

    const handleSocketMessage = (e)=>{
        try {
            let rawMessage = e.data,
                message = JSON.parse(rawMessage);

            if(!message.hasOwnProperty('eventFamily') || message['eventFamily'] != 'overlay' || 
                !message.hasOwnProperty('eventType') || !message.hasOwnProperty['data'])
                return;

            if(message['eventType'] == 'follow') {
                console.log("New Follow !! ", message['data'])
            } else if(message['eventType'] == 'subscribe') {
                console.log("New Sub !! ", message['data'])
            } else if(message['eventType'] == 'donation') {
                console.log("New dono !! ", message['data'])
            } else if(message['eventType'] == 'timer') {
                console.log("New timer !! ", message['data'])
            }
               
        } catch (ex) {
            console.log(ex)
        }
    };

    socket.addFamilyHandler("overlay", handleSocketMessage);
    

});